@@ -106,6 +106,9 @@ func Test_LoadServerCommonConf(t *testing.T) {
 				BindPort:               7009,
 				BindUDPPort:            7008,
 				KCPBindPort:            7007,
+				QUICKeepalivePeriod:    10,
+				QUICMaxIdleTimeout:     30,
+				QUICMaxIncomingStreams: 100000,
 				ProxyBindAddr:          "127.0.0.9",
 				VhostHTTPPort:          89,
 				VhostHTTPSPort:         449,
@@ -179,6 +182,9 @@ func Test_LoadServerCommonConf(t *testing.T) {
 				BindAddr:                "0.0.0.9",
 				BindPort:                7009,
 				BindUDPPort:             7008,
+				QUICKeepalivePeriod:     10,
+				QUICMaxIdleTimeout:      30,
+				QUICMaxIncomingStreams:  100000,
 				ProxyBindAddr:           "0.0.0.9",
 				VhostHTTPTimeout:        60,
 				DashboardAddr:           "0.0.0.0",
